saruman.tasks.iproute2 package
==============================

Submodules
----------

saruman.tasks.iproute2.interfaces module
----------------------------------------

.. automodule:: saruman.tasks.iproute2.interfaces
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: saruman.tasks.iproute2
    :members:
    :undoc-members:
    :show-inheritance:
